@@ -5,7 +5,7 @@ import os
 import sys
 
 if __name__ == "__main__":
-    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tcms.settings.product")
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tcms.settings.devel")
 
     from django.core.management import execute_from_command_line
 
