@@ -21,8 +21,8 @@ class SimpleMDE(forms.Textarea):
         rendered_string += """
 <input id="%s" type="file" style="display: none">
 <script>
-$(document).ready(function() {
-    markdownEditor = initSimpleMDE(document.getElementById('%s'), $('#%s'));
+$(() => {
+    window.markdownEditor = initSimpleMDE(document.getElementById('%s'), $('#%s'));
 });
 </script>
 """ % (
@@ -30,15 +30,12 @@ $(document).ready(function() {
             attrs["id"],
             self.file_upload_id,
         )
+        # note: initSimpleMDE() should be available in templates through bundle.js
 
         return rendered_string
 
     class Media:
         css = {"all": ["simplemde/dist/simplemde.min.css"]}
-        js = [
-            "simplemde/dist/simplemde.min.js",
-            "js/simplemde_security_override.js",
-        ]
 
 
 class DurationWidget(forms.Widget):
