@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    Helper which facilitate actual communications with Redmine.
+    Helper module which facilitate actual communications with Redmine.
 """
 from tcms.issuetracker.base import IntegrationThread
 
@@ -10,6 +10,8 @@ class RedmineThread(IntegrationThread):
     Execute Redmine REST API code in a thread!
 
     Executed from the IssueTracker interface methods.
+
+    :meta private:
     """
 
     def post_comment(self):
