@@ -1,4 +1,4 @@
-# Copyright (c) 2020 Alexander Todorov <atodorov@MrSenko.com>
+# Copyright (c) 2020,2022 Alexander Todorov <atodorov@MrSenko.com>
 
 from django.conf import settings
 from django.contrib.auth.backends import BaseBackend
@@ -12,6 +12,10 @@ class AnonymousViewBackend(BaseBackend):
     """
 
     def has_perm(self, user_obj, perm, obj=None):
+        # let other backends decide
+        if perm.startswith("auth."):
+            return False
+
         if perm.find(".view_") > -1 and (
             user_obj.is_anonymous or user_obj.username == settings.ANONYMOUS_USER_NAME
         ):
