@@ -1,6 +1,6 @@
 from django import forms
 
-from tcms.management.models import Build, Component, Product
+from tcms.management.models import Build, Classification, Component, Product
 from tcms.rpc.api.forms import UpdateModelFormMixin
 
 
@@ -32,3 +32,9 @@ class ProductForm(forms.ModelForm):
     class Meta:
         model = Product
         fields = "__all__"
+
+
+class ClassificationForm(forms.ModelForm):
+    class Meta:
+        model = Classification
+        fields = "__all__"
