@@ -92,6 +92,25 @@ DEFAULT_GROUPS = ["Tester"]
 # handler!
 AUTO_APPROVE_NEW_USERS = True
 
+# Password validation rules, see
+# https://docs.djangoproject.com/en/4.1/topics/auth/passwords/#enabling-password-validation
+AUTH_PASSWORD_VALIDATORS = [
+    {
+        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
+    },
+    {
+        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
+        "OPTIONS": {
+            "min_length": 10,
+        },
+    },
+    {
+        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
+    },
+    {
+        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
+    },
+]
 
 # Set to False if you want to enforce account creation by admins.
 REGISTRATION_ENABLED = (
@@ -317,7 +336,6 @@ for plugin in pkg_resources.iter_entry_points("kiwitcms.plugins"):
 
 # this is the main navigation menu
 MENU_ITEMS = [
-    (_("DASHBOARD"), reverse_lazy("core-views-index")),
     (
         _("TESTING"),
         [
