@@ -155,12 +155,11 @@ class NewFromPlan(NewTestRunView):
 
 @method_decorator(permission_required("testruns.view_testrun"), name="dispatch")
 class SearchTestRunView(TemplateView):
-
     template_name = "testruns/search.html"
 
     def get_context_data(self, **kwargs):
         form = SearchRunForm(self.request.GET)
-        form.populate(product_id=self.request.GET.get("product"))
+        form.populate(product_id=self.request.GET.get("product", -1))
 
         return {
             "form": form,
@@ -174,7 +173,6 @@ class SearchTestRunView(TemplateView):
     name="dispatch",
 )
 class GetTestRunView(DetailView):
-
     template_name = "testruns/get.html"
     http_method_names = ["get"]
     model = TestRun
@@ -278,6 +276,8 @@ class CloneTestRunView(NewTestRunView):
             "build": test_run.build_id,
             "default_tester": test_run.default_tester,
             "plan": test_run.plan_id,
+            "planned_start": test_run.planned_start,
+            "planned_stop": test_run.planned_stop,
         }
 
         return super().get(request, form_initial=form_initial, is_cloning=True)
