@@ -4,9 +4,9 @@ from django.db import transaction
 
 def delete_user(user):
     """
-        Delete user across DB schemas.
+    Delete user across DB schemas.
     """
-    if hasattr(user, 'tenant_set'):
+    if hasattr(user, "tenant_set"):
         from django_tenants.utils import schema_context  # pylint: disable=E0401, C0415
 
         user_id = user.pk
@@ -22,7 +22,7 @@ def delete_user(user):
                     user.pk = user_id
 
             # then delete everything from the public schema
-            with schema_context('public'):
+            with schema_context("public"):
                 user.delete()
 
     else:
